﻿using Microsoft.AspNetCore.Http;
using Microsoft.AspNetCore.Mvc;
using QRcare.API.Repositories;
using QRcare.Models;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;

namespace QRcare.API.Controllers
{
    [ApiController]
    [Route("/anamnesis")]
    public class AnamnesisController : ControllerBase
    {
        private readonly IAnamnesisRep anamnesisRep;

        public AnamnesisController(IAnamnesisRep anamnesisRep)
        {
            this.anamnesisRep = anamnesisRep;
        }

        [HttpGet("{patientId}")]
        public async Task<ActionResult<Anamnesis>> GetAnamnesis(string patientId)
        {
            try
            {
                var result = await anamnesisRep.GetAnamnesis(patientId);
                if(result is null)
                {
                    return NotFound();
                }
                return result;
            }
            catch (Exception)
            {
                return BadRequest();
            }
        }

        [HttpPut()]
        public async Task UpdateAnamnasis(Anamnesis anamnesis)
        {
            try
            {
                var result = await anamnesisRep.GetAnamnesis(anamnesis.PatientAnamnesisFK);
                if(result==null)
                {
                     NotFound();
                }
                await anamnesisRep.UpdateAnamnesis(anamnesis);
            }
            catch (Exception)
            {
                BadRequest();
            }
        }

        [HttpPost]
        public async Task AddAnamnesis(Anamnesis anamnesis)
        {
            try
            {
                if (anamnesis is null)
                {
                    BadRequest();
                }
                await anamnesisRep.AddAnamnesis(anamnesis);

            }
            catch (Exception)
            {
                BadRequest();
            }
        }
    }
}
