﻿using Microsoft.AspNetCore.Http;
using Microsoft.AspNetCore.Mvc;
using QRcare.API.Repositories;
using QRcare.Models;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;

namespace QRcare.API.Controllers
{
    [ApiController]
    [Route("/QRkey")]
    public class QRKeyController: ControllerBase
    {
        private readonly IQRKeyRep qrKeyRep;

        public QRKeyController(IQRKeyRep qrKeyRep)
        {
            this.qrKeyRep = qrKeyRep;
        }

        [HttpPost]
         public async Task<ActionResult<string>> GetQRKey (UserLogin user)
        {
            try
            {
               return await qrKeyRep.GetQRcodeKey(user);
            }
            catch (Exception)
            {
                return StatusCode(StatusCodes.Status500InternalServerError,
                    "Error retrieving data from the database");
            }
        }

        [HttpGet("/key/{QRkey}")]
        public async Task<ActionResult<string>> GetPatientId (string QRkey)
        {
            try
            {
                var result = await qrKeyRep.GetPatientId(QRkey);
                if (result is not null)
                {
                    return result;
                }
                return BadRequest();
            }
            catch (Exception)
            {
               return StatusCode(StatusCodes.Status500InternalServerError,
                    "Error retrieving data from the database");
            }
        }

        [HttpDelete("{PatientId}")]
        public async Task DeleteQRKey(string patientId)
        {
            try
            {
                 await qrKeyRep.DeleteQRKey(patientId);
            }
            catch (Exception)
            {
                 StatusCode(StatusCodes.Status500InternalServerError,
                     "Error retrieving data from the database");
            }
        }
    }
}
