﻿using Microsoft.EntityFrameworkCore;
using QRcare.Models;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;

namespace QRcare.API.Date
{
    public class QRcareDbContext : DbContext
    {
        public QRcareDbContext(DbContextOptions<QRcareDbContext> options)
            :base(options)
        {
        }
        public DbSet<PatientPersonalProfile> PatientPersonalProfiles { get; set; }
        public DbSet<Anamnesis> Anamnesis { get; set; }
        public DbSet<PresentDiagnose> PresentDiagnoses { get; set; }
        public DbSet<QRCodeKey> QRCodeKeys { get; set; }
        public DbSet<UserLogin> UserLogins { get; set; }

        protected override void OnModelCreating(ModelBuilder modelBuilder)
        {
            base.OnModelCreating(modelBuilder);
            modelBuilder.Entity<PatientPersonalProfile>()
                .HasKey(p => p.PatientId);
            modelBuilder.Entity<PatientPersonalProfile>()
               .HasOne(p=>p.Anamnesis)
               .WithOne(a => a.PatientPersonalProfile)
               .HasForeignKey<Anamnesis>(p=>p.PatientAnamnesisFK);
            modelBuilder.Entity<PatientPersonalProfile>()
               .HasMany(p => p.PresentDiagnoses)
               .WithOne(a => a.PatientPersonalProfile)
               .HasForeignKey(p=>p.PatientPresentFK);
            modelBuilder.Entity<PatientPersonalProfile>()
                .Property(p => p.PatientId)
                .HasMaxLength(20);
            modelBuilder.Entity<PatientPersonalProfile>()
                .Property(p => p.FirstName)
                .HasMaxLength(50);
            modelBuilder.Entity<PatientPersonalProfile>()
                .Property(p => p.LastName)
                .HasMaxLength(50);
            modelBuilder.Entity<PatientPersonalProfile>()
                .Property(p => p.InsuranceNumber)
                .HasMaxLength(10);
            modelBuilder.Entity<PatientPersonalProfile>()
                .Property(p => p.InsuranceKod)
                .HasMaxLength(3);
            modelBuilder.Entity<PatientPersonalProfile>()
                .Property(p => p.Gender)
                .HasMaxLength(10);
            modelBuilder.Entity<PatientPersonalProfile>()
                .Property(p => p.Email)
                .HasMaxLength(50);
            modelBuilder.Entity<PatientPersonalProfile>()
                .Property(p => p.PhoneNumber)
                .HasMaxLength(20);
            
            modelBuilder.Entity<PresentDiagnose>().HasKey
                (d => d.DiagnoseId);
            modelBuilder.Entity<PresentDiagnose>()
                .Property(p => p.DiagnoseId)
                .HasMaxLength(20);
            modelBuilder.Entity<PresentDiagnose>()
                .Property(p => p.PatientPresentFK)
                .HasMaxLength(20);

            modelBuilder.Entity<Anamnesis>().HasKey
                (a => a.AnamnesisId);
            modelBuilder.Entity<Anamnesis>()
                .Property(p => p.PatientAnamnesisFK)
                .HasMaxLength(20);
            modelBuilder.Entity<Anamnesis>()
                .Property(p => p.AnamnesisId)
                .HasMaxLength(20);

            modelBuilder.Entity<QRCodeKey>().HasKey
                (c =>  c.PatientKeyId);
            modelBuilder.Entity<QRCodeKey>()
                .Property(p => p.PatientKeyId)
                .HasMaxLength(20);
            modelBuilder.Entity<QRCodeKey>()
                .Property(p => p.QrKey)
                .HasMaxLength(20);

            modelBuilder.Entity<UserLogin>().HasKey
                (u => u.UserId );
            modelBuilder.Entity<UserLogin>()
                .Property(p => p.Password)
                .HasMaxLength(50);
            modelBuilder.Entity<UserLogin>()
                .Property(p => p.UserId)
                .HasMaxLength(20);
            modelBuilder.Entity<UserLogin>()
                .Property(p => p.UserName)
                .HasMaxLength(50);

            modelBuilder.Entity<PatientPersonalProfile>()
                .HasData(new PatientPersonalProfile
            {
                PatientId = "100",
                FirstName = "Mohammad",
                LastName = "Zabadi",
                DateOfBirht = new DateTime(1995, 8, 16),
                Gender = "Male",
                Email = "zabadi@gmail.com",
                PhoneNumber = "+470775421255",
                InsuranceNumber="3015558077",
                InsuranceKod="777",
            });
            modelBuilder.Entity<Anamnesis>().HasData(new Anamnesis
            {
                AnamnesisId = "1000",
                PatientAnamnesisFK="100",
                AllergicAnamnesis = "none",
                FamilyAnamnesis = "none",
                GynecologicalAnamnesis = "none",
                PharmacologicalAnamnesis = "none",
                SocialAnamnesis = "none",
                ToxicologicalAndAbuseAnamnesis = "none",
                WorkAnamnesis = "none",
                
            });
           
            modelBuilder.Entity<QRCodeKey>().HasData(new QRCodeKey
            {
                QrKey = "12345",
                PatientKeyId = "100",
            });
            modelBuilder.Entity<UserLogin>().HasData(new UserLogin
            {
                UserId = "100",
                Password = "0000",
                UserName = "mohammad",
                Role="Doctor"
            });

        }
    }
}
