﻿using System;
using Microsoft.EntityFrameworkCore.Migrations;

namespace QRcare.API.Migrations
{
    public partial class initialQRcare : Migration
    {
        protected override void Up(MigrationBuilder migrationBuilder)
        {
            migrationBuilder.CreateTable(
                name: "PatientPersonalProfiles",
                columns: table => new
                {
                    PatientId = table.Column<string>(type: "nvarchar(20)", maxLength: 20, nullable: false),
                    FirstName = table.Column<string>(type: "nvarchar(50)", maxLength: 50, nullable: false),
                    LastName = table.Column<string>(type: "nvarchar(50)", maxLength: 50, nullable: false),
                    DateOfBirht = table.Column<DateTime>(type: "datetime2", nullable: false),
                    Gender = table.Column<string>(type: "nvarchar(10)", maxLength: 10, nullable: false),
                    Email = table.Column<string>(type: "nvarchar(50)", maxLength: 50, nullable: false),
                    PhoneNumber = table.Column<string>(type: "nvarchar(20)", maxLength: 20, nullable: false),
                    InsuranceNumber = table.Column<string>(type: "nvarchar(10)", maxLength: 10, nullable: false),
                    InsuranceKod = table.Column<string>(type: "nvarchar(3)", maxLength: 3, nullable: false)
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_PatientPersonalProfiles", x => x.PatientId);
                });

            migrationBuilder.CreateTable(
                name: "QRCodeKeys",
                columns: table => new
                {
                    PatientKeyId = table.Column<string>(type: "nvarchar(20)", maxLength: 20, nullable: false),
                    QrKey = table.Column<string>(type: "nvarchar(20)", maxLength: 20, nullable: true)
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_QRCodeKeys", x => x.PatientKeyId);
                });

            migrationBuilder.CreateTable(
                name: "UserLogins",
                columns: table => new
                {
                    UserId = table.Column<string>(type: "nvarchar(20)", maxLength: 20, nullable: false),
                    UserName = table.Column<string>(type: "nvarchar(50)", maxLength: 50, nullable: false),
                    Password = table.Column<string>(type: "nvarchar(50)", maxLength: 50, nullable: false)
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_UserLogins", x => x.UserId);
                });

            migrationBuilder.CreateTable(
                name: "Anamnesis",
                columns: table => new
                {
                    AnamnesisId = table.Column<string>(type: "nvarchar(20)", maxLength: 20, nullable: false),
                    FamilyAnamnesis = table.Column<string>(type: "nvarchar(max)", nullable: true),
                    PharmacologicalAnamnesis = table.Column<string>(type: "nvarchar(max)", nullable: true),
                    ToxicologicalAndAbuseAnamnesis = table.Column<string>(type: "nvarchar(max)", nullable: true),
                    AllergicAnamnesis = table.Column<string>(type: "nvarchar(max)", nullable: true),
                    WorkAnamnesis = table.Column<string>(type: "nvarchar(max)", nullable: true),
                    SocialAnamnesis = table.Column<string>(type: "nvarchar(max)", nullable: true),
                    GynecologicalAnamnesis = table.Column<string>(type: "nvarchar(max)", nullable: true),
                    PatientAnamnesisFK = table.Column<string>(type: "nvarchar(20)", maxLength: 20, nullable: true)
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_Anamnesis", x => x.AnamnesisId);
                    table.ForeignKey(
                        name: "FK_Anamnesis_PatientPersonalProfiles_PatientAnamnesisFK",
                        column: x => x.PatientAnamnesisFK,
                        principalTable: "PatientPersonalProfiles",
                        principalColumn: "PatientId",
                        onDelete: ReferentialAction.Restrict);
                });

            migrationBuilder.CreateTable(
                name: "PresentDiagnoses",
                columns: table => new
                {
                    DiagnoseId = table.Column<string>(type: "nvarchar(20)", maxLength: 20, nullable: false),
                    DiagnoseDate = table.Column<DateTime>(type: "datetime2", nullable: false),
                    MinimumAnamnesis = table.Column<string>(type: "nvarchar(max)", nullable: false),
                    PresentIllness = table.Column<string>(type: "nvarchar(max)", nullable: false),
                    PatientPresentFK = table.Column<string>(type: "nvarchar(20)", maxLength: 20, nullable: false),
                    PatientPersonalProfilePatientId = table.Column<string>(type: "nvarchar(20)", nullable: false,computedColumnSql: "[PatientPresentFK]")
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_PresentDiagnoses", x => x.DiagnoseId);
                    table.ForeignKey(
                        name: "FK_PresentDiagnoses_PatientPersonalProfiles_PatientPersonalProfilePatientId",
                        column: x => x.PatientPersonalProfilePatientId,
                        principalTable: "PatientPersonalProfiles",
                        principalColumn: "PatientId",
                        onDelete: ReferentialAction.Cascade);
                });

            migrationBuilder.InsertData(
                table: "PatientPersonalProfiles",
                columns: new[] { "PatientId", "DateOfBirht", "Email", "FirstName", "Gender", "InsuranceKod", "InsuranceNumber", "LastName", "PhoneNumber" },
                values: new object[] { "100", new DateTime(1995, 8, 16, 0, 0, 0, 0, DateTimeKind.Unspecified), "zabadi@gmail.com", "Mohammad", "Male", "777", "3015558077", "Zabadi", "+470775421255" });

            migrationBuilder.InsertData(
                table: "QRCodeKeys",
                columns: new[] { "PatientKeyId", "QrKey" },
                values: new object[] { "100", "12345" });

            migrationBuilder.InsertData(
                table: "UserLogins",
                columns: new[] { "UserId", "Password", "UserName" },
                values: new object[] { "100", "0000", "mohammad" });

            migrationBuilder.InsertData(
                table: "Anamnesis",
                columns: new[] { "AnamnesisId", "AllergicAnamnesis", "FamilyAnamnesis", "GynecologicalAnamnesis", "PatientAnamnesisFK", "PharmacologicalAnamnesis", "SocialAnamnesis", "ToxicologicalAndAbuseAnamnesis", "WorkAnamnesis" },
                values: new object[] { "1000", "none", "none", "none", "100", "none", "none", "none", "none" });

            migrationBuilder.CreateIndex(
                name: "IX_Anamnesis_PatientAnamnesisFK",
                table: "Anamnesis",
                column: "PatientAnamnesisFK",
                unique: true,
                filter: "[PatientAnamnesisFK] IS NOT NULL");

            migrationBuilder.CreateIndex(
                name: "IX_PresentDiagnoses_PatientPersonalProfilePatientId",
                table: "PresentDiagnoses",
                column: "PatientPersonalProfilePatientId");
        }

        protected override void Down(MigrationBuilder migrationBuilder)
        {
            migrationBuilder.DropTable(
                name: "Anamnesis");

            migrationBuilder.DropTable(
                name: "PresentDiagnoses");

            migrationBuilder.DropTable(
                name: "QRCodeKeys");

            migrationBuilder.DropTable(
                name: "UserLogins");

            migrationBuilder.DropTable(
                name: "PatientPersonalProfiles");
        }
    }
}
