using Microsoft.AspNetCore.Builder;
using Microsoft.AspNetCore.Hosting;
using Microsoft.EntityFrameworkCore;
using Microsoft.AspNetCore.HttpsPolicy;
using Microsoft.AspNetCore.Mvc;
using Microsoft.Extensions.Configuration;
using Microsoft.Extensions.DependencyInjection;
using Microsoft.Extensions.Hosting;
using Microsoft.Extensions.Logging;
using Microsoft.OpenApi.Models;
using QRcare.API.Date;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;
using QRcare.API.Repositories;
using Microsoft.AspNetCore.Authentication.Cookies;

namespace QRcare.API
{
    public class Startup
    {
        public Startup(IConfiguration configuration)
        {
            Configuration = configuration;
        }

        public IConfiguration Configuration { get; }

        // This method gets called by the runtime. Use this method to add services to the container.
        public void ConfigureServices(IServiceCollection services)
        {
            services.AddCors(policy =>
            {
                policy.AddPolicy("OpenPolicy", opt =>
                opt.AllowAnyHeader()
                .AllowAnyMethod()
                .AllowAnyOrigin()
                );
            });
            services.AddDbContext<QRcareDbContext>(options =>
            options.UseSqlServer(Configuration.GetConnectionString("DBConnection")));
            services.AddControllers();
            services.AddScoped<IPatientRep, PatientRep>();
            services.AddScoped<IAnamnesisRep, AnamnesisRep>();
            services.AddScoped<IPresentDiagnoseRep, PresentDiagnoseRep>();
            services.AddScoped<IQRKeyRep, QRKeyRep>();
            services.AddScoped<ILoginRep, LoginRep>();


            services.AddSwaggerGen(c =>
            {
                c.SwaggerDoc("v1", new OpenApiInfo { Title = "QRcare.API", Version = "v1" });
            });

            services.AddAuthentication(options =>
            {
                options.DefaultScheme = CookieAuthenticationDefaults.AuthenticationScheme;
            }).AddCookie();
        }

        // This method gets called by the runtime. Use this method to configure the HTTP request pipeline.
        public void Configure(IApplicationBuilder app, IWebHostEnvironment env)
        {
            if (env.IsDevelopment())
            {
                app.UseDeveloperExceptionPage();
                app.UseSwagger();
                app.UseSwaggerUI(c => c.SwaggerEndpoint("/swagger/v1/swagger.json", "QRcare.API v1"));
            }

            app.UseHttpsRedirection();

            app.UseCors("OpenPolicy");

            app.UseRouting();

            app.UseAuthorization();

            app.UseEndpoints(endpoints =>
            {
                endpoints.MapControllers();
            });
        }
    }
}
