﻿using Newtonsoft.Json;
using Plugin.Fingerprint;
using Plugin.Fingerprint.Abstractions;
using QRcare.Models;
using QRcare.Services;
using QRcare.Views;
using System;
using System.Collections.Generic;
using System.Text;
using Xamarin.Essentials;
using Xamarin.Forms;
using Xamarin.Forms.PlatformConfiguration;

namespace QRcare.ViewModels
{
    public class LoginViewModel : BaseViewModel
    {

        public Command LoginCommand { get; }
        public Command LoginFingerPrintCommand { get; }
        private string username;
        private string password;
        public LoginViewModel()
        {
            LoginCommand = new Command(OnLoginClicked);
            LoginFingerPrintCommand = new Command(OnLoginFingerPrintCommand);
            Title = "Login";
        }

        public async void OnAppearing()
        {
            if (Connectivity.NetworkAccess != NetworkAccess.Internet)
            {
                var action = await Application.Current.MainPage.DisplayAlert("Error", "No internet connection", "", "Try Again");
                if (!action)
                    OnAppearing();
            }
            Connectivity.ConnectivityChanged += Connectivity_ConnectivityChanged;
            Username = Preferences.Get("Username", string.Empty);
            Password = string.Empty;
        }

        private async void Connectivity_ConnectivityChanged(object sender, ConnectivityChangedEventArgs e)
        {
            await Shell.Current.GoToAsync($"//{nameof(LoginPage)}");
        }

        public string Username
        {
            get { return username; }
            set
            {
                SetProperty(ref username, value);
            }
        }
        public string Password
        {
            get { return password; }
            set
            {
                SetProperty(ref password, value);
            }
        }
        private async void OnLoginClicked(object obj)
        {
            var isAuth =await QRKeyService.Auth(Username, Password);
            if (isAuth !=null)
            {
                Preferences.Set("Username",isAuth.UserName);
                Preferences.Set("Password", isAuth.Password);
                Preferences.Set("UserId", isAuth.UserId);

                await DataStore.AddUserAsync(isAuth);
                await Shell.Current.GoToAsync($"//{nameof(HomePage)}");
            }
            else
            {
                await Application.Current.MainPage.DisplayAlert("Unauthorized", "The username or password is not correct, please try again.", "OK");
            }
        }
        private async void OnLoginFingerPrintCommand(object obj)
        {
            
            string user = Preferences.Get("Username", string.Empty);
            string password = Preferences.Get("Password", string.Empty);
            var available = await CrossFingerprint.Current.IsAvailableAsync();
            if (!available)
            {
                await Application.Current.MainPage.DisplayAlert("Error", "Fingerprint is not available, please login using password", "Cancel");
                return ;
            }
            
            if (!String.IsNullOrEmpty(user))
            {
                var authResult = await CrossFingerprint.Current.AuthenticateAsync
               (new AuthenticationRequestConfiguration("Fingerprint Login", "Do You want to login using Your Fingerprint?"));
                if (authResult.Authenticated)
                {
                    var isAuth = await QRKeyService.Auth(user, password);
                    if (isAuth != null)
                    {
                        await DataStore.AddUserAsync(isAuth);
                        await Shell.Current.GoToAsync($"//{nameof(HomePage)}");
                    }
                    else
                    {
                        Preferences.Clear();
                        await Application.Current.MainPage.DisplayAlert("Unauthorized", "The username or password were changed, please login using your password", "OK");
                        return;
                    }
                }
                else
                {
                    await Application.Current.MainPage.DisplayAlert("Unauthorized", "Fingerprint is not recognised, please try again", "OK");
                    return;
                }
            }
            else
            {
                await Application.Current.MainPage.DisplayAlert("Unauthorized", "password is required for the first login", "OK");
                return;
            }
        }
    }
}
 