﻿using Microsoft.AspNetCore.Components;
using Microsoft.AspNetCore.Components.Web;
using QRcare.Models;
using QRcare.WebApp.Components;
using QRcare.WebApp.Serviceses;
using Syncfusion.Blazor.Grids;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;

namespace QRcare.WebApp.Pages
{
    public class PatientPageBase: ComponentBase
    {
        [Inject]
        public IPatientSer PatientSer { get; set; }
        [Inject]
        public IPresentDiagnoseSer PresentDiagnoseSer { get; set; }
        [Inject]
        public IAnamnesisSer AnamnesisSer { get; set; }
        [Inject]
        NavigationManager NavigationManager { get; set; }
        [Parameter]
        public string PatientId { get; set; }
        public PatientPersonalProfile PatientPersonalProfile { get; set; }
        public IEnumerable<PresentDiagnose> PresentDiagnoses { get; set; }
        public Anamnesis Anamnesis { get; set; }
        public bool CollapsedAnamnesis = true;
        public bool OpenedDiagnoseModal { get; set; } = false;
        public bool ToAdd { get; set; }

        //public DiagnoseModalComponents DiagnoseModal { get; set; }
        public PresentDiagnose ShownDiagnose { get; set; }
        protected async override Task OnInitializedAsync()
        {
            PatientPersonalProfile = await PatientSer.GetPatient(PatientId);
            if (PatientPersonalProfile is null)
            {
                NavigationManager.NavigateTo("404");
            }
            else
            {
                PresentDiagnoses = (await PresentDiagnoseSer.GetPresentDiagnoses(PatientId)).ToList();
                Anamnesis = await AnamnesisSer.GetAnamnesis(PatientId);
            }
        }
       public void ShowDiagnoseModal(PresentDiagnose presentDiagnose)
        {
            ToAdd = false;
            ShownDiagnose = presentDiagnose;
            OpenedDiagnoseModal = true;
        }
        public void AddDiagnose()
        {
            ToAdd = true;
            ShownDiagnose = new PresentDiagnose() { PatientPresentFK =PatientId, DiagnoseDate=DateTime.Now,DiagnoseId="null" };
            OpenedDiagnoseModal = true;
        }
        public async Task ModelClose(bool Added)
        {
            if (Added)
            {
                OpenedDiagnoseModal = false;
                StateHasChanged();
                PresentDiagnoses = (await PresentDiagnoseSer.GetPresentDiagnoses(PatientId)).ToList();
                Body = "Diagnose was added Successfully";
                NotificationColor = "is-primary";
                await ShowMassage();
            }
            else
            {
                OpenedDiagnoseModal = false;
                StateHasChanged();
                if (ToAdd)
                {
                    Body = "Diagnose was discarded";
                    NotificationColor = "is-danger";
                    await ShowMassage();
                }
                
            }
            
        }
        #region NotificationRegion
        public bool ChangesApplied { get; set; } = false;
        public string Body { get; set; }
        public string NotificationColor { get; set; }

        private async Task ShowMassage()
        {
            ChangesApplied = true;
            StateHasChanged();
            await Task.Delay(5000);
            ChangesApplied = false;
            StateHasChanged();
        }

        #endregion
    }
}
